#!/bin/bash

# This script will configure your system to meet the requirements that are needed to run instant3Dhub.
# Please note that the script needs root privileges and should be run using sudo. 
# A system reboot is required after executing the script.

# Update Server and Install snap
echo 'Updating the server and installing snap ...'

# Update the server
dnf install epel-release -y
dnf update -y

# Install snapd
dnf -y install snapd

# Enable the systemd unit that manages the main snap communication socket
systemctl enable --now snapd.socket

#  Add snap to PATH variable
ln -s /var/lib/snapd/snap /snap
export PATH="$PATH:/snap/bin"
echo 'export PATH=$PATH:/var/lib/snapd/snap/bin' | sudo tee -a /etc/profile.d/mysnap.sh

# Disable SELinux
setenforce 0
sed -i 's/^SELINUX=.*/SELINUX=permissive/g' /etc/selinux/config

# When GPU support is needed, the NVIDIA driver requires that the kernel headers and development packages for the running version of the kernel be installed 
# at the time of the driver installation, as well whenever the driver is rebuilt. For example, if your system is running kernel version 4.4.0, the 4.4.0 kernel headers and development packages must also be installed.
# Ensure that the system has the correct Linux kernel sources from the CentOS repositories:
dnf install -y kernel-devel-$(uname -r) kernel-headers-$(uname -r)
# If the previous command failed, please reboot your machine and try again

# Wait till snap is ready
snap wait system seed.loaded

# Disable nouveau dirver (This requires rebooting)
grub2-editenv - set "$(grub2-editenv - list | grep kernelopts) nouveau.modeset=0"

# Make sure firewalld masquerade is enabled on the host:
firewall-cmd --add-masquerade --permanent
firewall-cmd --reload 
